import semver from 'semver';
import { getGitHookPaths } from '../../util/git.js';
import { timerify } from '../../util/Performance.js';
import { getDependenciesFromScripts, hasDependency, loadFile } from '../../util/plugin.js';
const NAME = 'husky';
const ENABLERS = ['husky'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const gitHooksPathInV8 = getGitHookPaths('.husky', true);
const gitHookPathsInV9 = getGitHookPaths('.husky', false);
const CONFIG_FILE_PATTERNS = [...gitHooksPathInV8, ...gitHookPathsInV9];
const findHuskyDependencies = async (configFilePath, options) => {
    const { isProduction, manifest } = options;
    if (isProduction)
        return [];
    const huskyVersion = manifest.devDependencies?.husky ?? manifest.dependencies?.husky ?? '*';
    const isV8OrLower = semver.intersects(huskyVersion, '<9', {
        includePrerelease: true,
    });
    if (!isV8OrLower && gitHooksPathInV8.some(path => configFilePath.includes(path))) {
        return [];
    }
    const isV9OrHigher = semver.intersects(huskyVersion, '>=9', {
        includePrerelease: true,
    });
    if (!isV9OrHigher && gitHookPathsInV9.some(path => configFilePath.includes(path))) {
        return [];
    }
    const script = await loadFile(configFilePath);
    if (!script)
        return [];
    return getDependenciesFromScripts(String(script), { ...options, knownGlobalsOnly: true });
};
const findDependencies = timerify(findHuskyDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    CONFIG_FILE_PATTERNS,
    findDependencies,
};
