import { basename } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
const NAME = 'Prettier';
const ENABLERS = ['prettier'];
const isEnabled = ({ dependencies, config }) => hasDependency(dependencies, ENABLERS) || 'prettier' in config;
const CONFIG_FILE_PATTERNS = [
    '.prettierrc',
    '.prettierrc.{json,js,cjs,mjs,yml,yaml}',
    'prettier.config.{js,cjs,mjs}',
    'package.json',
];
const findPrettierDependencies = async (configFilePath, { manifest, isProduction }) => {
    if (isProduction)
        return [];
    const localConfig = basename(configFilePath) === 'package.json' ? manifest.prettier : await load(configFilePath);
    if (typeof localConfig === 'string') {
        return [localConfig];
    }
    return localConfig && Array.isArray(localConfig.plugins)
        ? localConfig.plugins.filter((plugin) => typeof plugin === 'string')
        : [];
};
const findDependencies = timerify(findPrettierDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    CONFIG_FILE_PATTERNS,
    findDependencies,
};
